==> haskell-temporary-1.3-897.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl
key:                  temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  d203ad0190102f8d00b650d2e48755fa
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-9.6.6/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/temporary-1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-temporary
hs-libraries:         HStemporary-1.3-DmygwHaZA8GJCfyTYb6Tkl
depends:
    base-4.18.2.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.3-899-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-29RL4tTXoFB72QSCtJnhBC
key:                  temporary-1.3-29RL4tTXoFB72QSCtJnhBC
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  7ee4ce0ea7161c81d77f56106bf4ec36
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-9.6.6/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/temporary-1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-temporary
hs-libraries:         HStemporary-1.3-29RL4tTXoFB72QSCtJnhBC
depends:
    base-4.18.2.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
